=== modified file 'client/drizzleslap.cc'
--- client/drizzleslap.cc	2008-12-09 04:10:34 +0000
+++ client/drizzleslap.cc	2008-12-17 05:39:06 +0000
@@ -2605,7 +2605,7 @@
     return;
 
   if (opt_delayed_start)
-    my_sleep(random()%opt_delayed_start);
+    usleep(random()%opt_delayed_start);
 
   drizzle_create(drizzle);
 
@@ -2626,7 +2626,7 @@
       connect_error= 0;
       break;
     }
-    my_sleep(connection_retry_sleep);
+    usleep(connection_retry_sleep);
   }
   if (connect_error)
   {

=== modified file 'client/drizzletest.cc'
--- client/drizzletest.cc	2008-12-16 20:57:39 +0000
+++ client/drizzletest.cc	2008-12-17 18:23:08 +0000
@@ -2493,8 +2493,8 @@
 
 static void do_mkdir(struct st_command *command)
 {
+  string ds_dirname;
   int error;
-  string ds_dirname;
   const struct command_arg mkdir_args[] = {
     {"dirname", ARG_STRING, true, &ds_dirname, "Directory to create"}
   };
@@ -2504,7 +2504,7 @@
                      mkdir_args, sizeof(mkdir_args)/sizeof(struct command_arg),
                      ' ');
 
-  error= my_mkdir(ds_dirname.c_str(), 0777, MYF(0)) != 0;
+  error= mkdir(ds_dirname.c_str(), (0777 & my_umask_dir)) != 0;
   handle_command_error(command, error);
   return;
 }
@@ -3015,7 +3015,7 @@
     drizzle_free_result(res);
     if (done)
       break;
-    my_sleep(SLAVE_POLL_INTERVAL);
+    usleep(SLAVE_POLL_INTERVAL);
   }
   return;
 }
@@ -3218,7 +3218,7 @@
     sleep_val= opt_sleep;
 
   if (sleep_val)
-    my_sleep((uint32_t) (sleep_val * 1000000L));
+    usleep((uint32_t) (sleep_val * 1000000L));
   command->last_argument= sleep_end;
   return 0;
 }
@@ -3609,7 +3609,7 @@
       verbose_msg("Connect attempt %d/%d failed: %d: %s", failed_attempts,
                   opt_max_connect_retries, drizzle_errno(drizzle),
                   drizzle_error(drizzle));
-      my_sleep(connection_retry_sleep);
+      usleep(connection_retry_sleep);
     }
     else
     {

=== modified file 'drizzled/db.cc'
--- drizzled/db.cc	2008-12-14 08:26:38 +0000
+++ drizzled/db.cc	2008-12-17 05:39:06 +0000
@@ -592,7 +592,7 @@
       my_error(EE_STAT, MYF(0), path, errno);
       goto exit;
     }
-    if (my_mkdir(path,0777,MYF(0)) < 0)
+    if (mkdir(path,0777) < 0)
     {
       my_error(ER_CANT_CREATE_DB, MYF(0), db, my_errno);
       error= -1;

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2008-12-17 01:09:50 +0000
+++ drizzled/drizzled.cc	2008-12-17 18:23:08 +0000
@@ -878,7 +878,7 @@
   {
     if (pthread_kill(signal_thread, DRIZZLE_KILL_SIGNAL) != ESRCH)
       break;
-    my_sleep(100);				// Give it time to die
+    usleep(100);				// Give it time to die
   }
 }
 
@@ -1269,7 +1269,12 @@
 
   segfaulted = 1;
 
-  curr_time= my_time(0);
+  if((curr_time= time(0)) == (time_t)-1)
+  {
+    fprintf(stderr, "Fetal: time() call failed\n");
+    exit(1);
+  }
+
   localtime_r(&curr_time, &tm);
 
   fprintf(stderr,"%02d%02d%02d %2d:%02d:%02d - drizzled got "
@@ -1827,14 +1832,18 @@
 };
 
 static int init_common_variables(const char *conf_file_name, int argc,
-				 char **argv, const char **groups)
+                                 char **argv, const char **groups)
 {
+  time_t current;
   umask(((~my_umask) & 0666));
   my_decimal_set_zero(&decimal_zero); // set decimal_zero constant;
   tzset();			// Set tzname
 
+  if ((current= time(0)) == (time_t)-1)
+    return 1;
+
   max_system_variables.pseudo_thread_id= UINT32_MAX;
-  server_start_time= flush_status_time= my_time(0);
+  server_start_time= flush_status_time= current;
 
   if (init_thread_environment())
     return 1;

=== modified file 'drizzled/function/time/sysdate_local.cc'
--- drizzled/function/time/sysdate_local.cc	2008-12-12 20:40:37 +0000
+++ drizzled/function/time/sysdate_local.cc	2008-12-17 07:16:37 +0000
@@ -30,7 +30,7 @@
 void Item_func_sysdate_local::store_now_in_TIME(DRIZZLE_TIME *now_time)
 {
   Session *session= current_session;
-  session->variables.time_zone->gmt_sec_to_TIME(now_time, (my_time_t) my_time(0));
+  session->variables.time_zone->gmt_sec_to_TIME(now_time, (my_time_t) time(0));
 }
 
 

=== modified file 'drizzled/log.cc'
--- drizzled/log.cc	2008-12-10 18:33:08 +0000
+++ drizzled/log.cc	2008-12-17 07:16:37 +0000
@@ -1939,7 +1939,7 @@
     new_file_without_locking();
     if (expire_logs_days)
     {
-      time_t purge_time= my_time(0) - expire_logs_days*24*60*60;
+      time_t purge_time= time(0) - expire_logs_days*24*60*60;
       if (purge_time >= 0)
         purge_logs_before_date(purge_time);
     }

=== modified file 'drizzled/log_event.cc'
--- drizzled/log_event.cc	2008-12-15 07:27:18 +0000
+++ drizzled/log_event.cc	2008-12-17 07:16:37 +0000
@@ -499,9 +499,9 @@
   :temp_buf(0), exec_time(0), flags(0), cache_stmt(0),
    session(0)
 {
-  server_id=	::server_id;
+  server_id= ::server_id;
   /*
-    We can't call my_time() here as this would cause a call before
+    We can't call time() here as this would cause a call before
     my_init() is called
   */
   when=		0;
@@ -748,7 +748,7 @@
     return session->start_time;
   if ((tmp_session= current_session))
     return tmp_session->start_time;
-  return my_time(0);
+  return time(0);
 }
 
 
@@ -4606,7 +4606,12 @@
       problem.  When WL#2975 is implemented, just remove the member
       Relay_log_info::last_event_start_time and all its occurrences.
     */
-    const_cast<Relay_log_info*>(rli)->last_event_start_time= my_time(0);
+    time_t t= time(0);
+
+    /* don't trust time() all the time */
+    if (t == (time_t)-1)
+      return (-1);
+    const_cast<Relay_log_info*>(rli)->last_event_start_time= time(0);
   }
 
   return(0);

=== modified file 'drizzled/show.cc'
--- drizzled/show.cc	2008-12-16 06:33:48 +0000
+++ drizzled/show.cc	2008-12-17 08:26:06 +0000
@@ -1206,7 +1206,7 @@
   pthread_mutex_unlock(&LOCK_thread_count);
 
   thread_info *session_info;
-  time_t now= my_time(0);
+  time_t now= time(0);
   while ((session_info=thread_infos.get()))
   {
     protocol->prepare_for_resend();
@@ -1236,7 +1236,10 @@
   Table *table= tables->table;
   const CHARSET_INFO * const cs= system_charset_info;
   char *user;
-  time_t now= my_time(0);
+  time_t now;
+
+  if ((now= time(0)) == (time_t)-1)
+    return 1;
 
   user= NULL;
 

=== modified file 'drizzled/slave.cc'
--- drizzled/slave.cc	2008-12-16 07:47:35 +0000
+++ drizzled/slave.cc	2008-12-17 18:23:08 +0000
@@ -1362,16 +1362,19 @@
   return(0);
 }
 
-
+/* Returns non zero on error */
 static int32_t safe_sleep(Session* session, int32_t sec, CHECK_KILLED_FUNC thread_killed,
-                      void* thread_killed_arg)
+                          void* thread_killed_arg)
 {
   int32_t nap_time;
   thr_alarm_t alarmed;
 
   thr_alarm_init(&alarmed);
-  time_t start_time= my_time(0);
-  time_t end_time= start_time+sec;
+  time_t start_time, end_time;
+
+  if ((start_time= time(0)) == (time_t)-1)
+    return -1;
+  end_time= start_time+sec;
 
   while ((nap_time= (int32_t) (end_time - start_time)) > 0)
   {
@@ -1387,7 +1390,8 @@
 
     if ((*thread_killed)(session,thread_killed_arg))
       return(1);
-    start_time= my_time(0);
+    if ((start_time= time(0)) == (time_t)-1)
+      return -1;
   }
   return(0);
 }
@@ -1604,7 +1608,9 @@
   session->set_time();                            // time the query
   session->lex->current_select= 0;
   if (!ev->when)
-    ev->when= my_time(0);
+    if((ev->when= time(0)) == (time_t)-1)
+      return 2;
+
   ev->session = session; // because up to this point, ev->session == 0
 
   if (skip)

=== modified file 'mysys/Makefile.am'
--- mysys/Makefile.am	2008-12-16 05:39:00 +0000
+++ mysys/Makefile.am	2008-12-17 18:23:08 +0000
@@ -100,12 +100,10 @@
 		my_init.cc \
 		my_lib.cc \
 		my_messnc.cc \
-		my_mkdir.cc \
 		my_open.cc \
 		my_read.cc \
 		my_redel.cc \
 		my_rename.cc \
-		my_sleep.cc \
 		my_static.cc \
 		my_symlink.cc \
 		my_symlink2.cc \

=== modified file 'mysys/mf_getdate.cc'
--- mysys/mf_getdate.cc	2008-11-26 05:12:21 +0000
+++ mysys/mf_getdate.cc	2008-12-17 07:16:37 +0000
@@ -43,7 +43,7 @@
   struct tm tm_tmp;
 #endif
 
-   skr=date ? (time_t) date : my_time(0);
+   skr= date ? (time_t) date : time(0);
 #if defined(HAVE_LOCALTIME_R) && defined(_REENTRANT)
    if (flag & GETDATE_GMT)
      localtime_r(&skr,&tm_tmp);

=== modified file 'mysys/my_create.cc'
--- mysys/my_create.cc	2008-12-16 02:39:00 +0000
+++ mysys/my_create.cc	2008-12-17 18:23:08 +0000
@@ -29,7 +29,7 @@
 
 
 File my_create(const char *FileName, int CreateFlags, int access_flags,
-	       myf MyFlags)
+               myf MyFlags)
 {
   int fd, rc;
 

=== modified file 'mysys/my_getsystime.cc'
--- mysys/my_getsystime.cc	2008-12-06 19:42:46 +0000
+++ mysys/my_getsystime.cc	2008-12-17 07:16:37 +0000
@@ -50,35 +50,6 @@
 #endif
 }
 
-
-/*
-  Return current time
-
-  SYNOPSIS
-    my_time()
-    flags	If MY_WME is set, write error if time call fails
-
-*/
-
-time_t my_time(myf flags)
-{
-  time_t t;
-#ifdef HAVE_GETHRTIME
-  (void)flags;
-  (void) my_micro_time_and_time(&t);
-  return t;
-#else
-  /* The following loop is here beacuse time() may fail on some systems */
-  while ((t= time(0)) == (time_t) -1)
-  {
-    if (flags & MY_WME)
-      fprintf(stderr, "%s: Warning: time() call failed\n", my_progname);
-  }
-  return t;
-#endif
-}
-
-
 /*
   Return time in micro seconds
 

=== removed file 'mysys/my_mkdir.cc'
--- mysys/my_mkdir.cc	2008-11-07 00:35:38 +0000
+++ mysys/my_mkdir.cc	1970-01-01 00:00:00 +0000
@@ -1,31 +0,0 @@
-/* Copyright (C) 2000 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-#include "mysys_priv.h"
-#include "mysys_err.h"
-#include <sys/types.h>
-#include <sys/stat.h>
-
-int my_mkdir(const char *dir, int Flags, myf MyFlags)
-{
-  if (mkdir((char*) dir, Flags & my_umask_dir))
-  {
-    my_errno=errno;
-    if (MyFlags & (MY_FFNF | MY_FAE | MY_WME))
-      my_error(EE_CANT_MKDIR,  MYF(ME_BELL+ME_WAITTANG), dir, my_errno);
-    return(-1);
-  }
-  return(0);
-}

=== removed file 'mysys/my_sleep.cc'
--- mysys/my_sleep.cc	2008-11-07 00:35:38 +0000
+++ mysys/my_sleep.cc	1970-01-01 00:00:00 +0000
@@ -1,33 +0,0 @@
-/* Copyright (C) 2000 MySQL AB
-
-   This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */
-
-/* Wait a given number of microseconds */
-
-#include "mysys_priv.h"
-#include <mystrings/m_string.h>
-
-void my_sleep(uint32_t m_seconds)
-{
-#if defined(HAVE_SELECT)
-  struct timeval t;
-  t.tv_sec=  m_seconds / 1000000L;
-  t.tv_usec= m_seconds % 1000000L;
-  select(0,0,0,0,&t); /* sleep */
-#else
-  uint32_t sec=    (uint) (m_seconds / 1000000L);
-  uint32_t start= (uint32_t) time((time_t*) 0);
-  while ((uint32_t) time((time_t*) 0) < start+sec);
-#endif
-}

=== modified file 'mysys/thr_alarm.cc'
--- mysys/thr_alarm.cc	2008-12-07 23:42:51 +0000
+++ mysys/thr_alarm.cc	2008-12-17 07:16:37 +0000
@@ -164,7 +164,12 @@
   bool reschedule;
   struct st_my_thread_var *current_my_thread_var= my_thread_var;
 
-  now= my_time(0);
+  if((now= time(0)) == (time_t)-1)
+  {
+    fprintf(stderr, "%s: Warning: time() call failed\n", my_progname);
+    return 1;
+  }
+
 #ifndef USE_ONE_SIGNAL_HAND
   pthread_sigmask(SIG_BLOCK,&full_signal_set,&old_mask);
 #endif
@@ -328,45 +333,45 @@
       uint32_t i;
       for (i=0 ; i < alarm_queue.elements ;)
       {
-	alarm_data=(ALARM*) queue_element(&alarm_queue,i);
-	alarm_data->alarmed=1;			/* Info to thread */
-	if (pthread_equal(alarm_data->thread,alarm_thread) ||
-	    pthread_kill(alarm_data->thread, thr_client_alarm))
-	{
-	  queue_remove(&alarm_queue,i);		/* No thread. Remove alarm */
-	}
-	else
-	  i++;					/* Signal next thread */
+        alarm_data=(ALARM*) queue_element(&alarm_queue,i);
+        alarm_data->alarmed=1;			/* Info to thread */
+        if (pthread_equal(alarm_data->thread,alarm_thread) ||
+            pthread_kill(alarm_data->thread, thr_client_alarm))
+        {
+          queue_remove(&alarm_queue,i);		/* No thread. Remove alarm */
+        }
+        else
+          i++;					/* Signal next thread */
       }
 #ifndef USE_ALARM_THREAD
       if (alarm_queue.elements)
-	alarm(1);				/* Signal soon again */
+        alarm(1);				/* Signal soon again */
 #endif
     }
     else
     {
-      uint32_t now=(uint32_t) my_time(0);
-      uint32_t next=now+10-(now%10);
+      uint32_t now= time(0);
+      uint32_t next= now+10-(now%10);
       while ((alarm_data=(ALARM*) queue_top(&alarm_queue))->expire_time <= now)
       {
-	alarm_data->alarmed=1;			/* Info to thread */
-	if (pthread_equal(alarm_data->thread,alarm_thread) ||
-	    pthread_kill(alarm_data->thread, thr_client_alarm))
-	{
-	  queue_remove(&alarm_queue,0);		/* No thread. Remove alarm */
-	  if (!alarm_queue.elements)
-	    break;
-	}
-	else
-	{
-	  alarm_data->expire_time=next;
-	  queue_replaced(&alarm_queue);
-	}
+        alarm_data->alarmed=1;			/* Info to thread */
+        if (pthread_equal(alarm_data->thread,alarm_thread) ||
+            pthread_kill(alarm_data->thread, thr_client_alarm))
+        {
+          queue_remove(&alarm_queue,0);		/* No thread. Remove alarm */
+          if (!alarm_queue.elements)
+            break;
+        }
+        else
+        {
+          alarm_data->expire_time=next;
+          queue_replaced(&alarm_queue);
+        }
       }
 #ifndef USE_ALARM_THREAD
       if (alarm_queue.elements)
       {
-	alarm((uint) (alarm_data->expire_time-now));
+        alarm((uint) (alarm_data->expire_time-now));
         next_alarm_expire_time= alarm_data->expire_time;
       }
 #endif
@@ -473,7 +478,7 @@
   info->max_used_alarms= max_used_alarms;
   if ((info->active_alarms=  alarm_queue.elements))
   {
-    uint32_t now=(uint32_t) my_time(0);
+    uint32_t now= (uint32_t)time(0);
     long time_diff;
     ALARM *alarm_data= (ALARM*) queue_top(&alarm_queue);
     time_diff= (long) (alarm_data->expire_time - now);
@@ -501,7 +506,12 @@
 #define tv_nsec ts_nsec
 #endif
 
-/* set up a alarm thread with uses 'sleep' to sleep between alarms */
+/* 
+   Set up a alarm thread which uses 'sleep' to sleep between alarms
+
+  RETURNS
+    NULL on time() failure
+*/
 
 #ifdef USE_ALARM_THREAD
 static void *alarm_handler(void *arg __attribute__((unused)))
@@ -515,21 +525,28 @@
   {
     if (alarm_queue.elements)
     {
-      uint32_t sleep_time,now= my_time(0);
+      uint32_t sleep_time, now;
+
+      if ((now= time(0)) == (time_t)-1)
+      {
+        pthread_mutex_unlock(&LOCK_alarm);
+        return NULL;
+      }
+
       if (alarm_aborted)
-	sleep_time=now+1;
+        sleep_time=now+1;
       else
-	sleep_time= ((ALARM*) queue_top(&alarm_queue))->expire_time;
+        sleep_time= ((ALARM*) queue_top(&alarm_queue))->expire_time;
       if (sleep_time > now)
       {
-	abstime.tv_sec=sleep_time;
-	abstime.tv_nsec=0;
+        abstime.tv_sec=sleep_time;
+        abstime.tv_nsec=0;
         next_alarm_expire_time= sleep_time;
-	if ((error=pthread_cond_timedwait(&COND_alarm,&LOCK_alarm,&abstime)) &&
-	    error != ETIME && error != ETIMEDOUT)
-	{
+        if ((error=pthread_cond_timedwait(&COND_alarm,&LOCK_alarm,&abstime)) &&
+            error != ETIME && error != ETIMEDOUT)
+        {
           assert(1);
-	}
+        }
       }
     }
     else if (alarm_aborted == -1)

